Welcome to aiocouchdb's documentation!
**************************************

.. contents::

Server
======

.. autoclass:: aiocouchdb.server.Server
  :members:

Configuration
-------------

.. autoclass:: aiocouchdb.server.Config
  :members:

Session
-------

.. autoclass:: aiocouchdb.server.Session
  :members:

Database
========

.. autoclass:: aiocouchdb.database.Database
  :members:

.. autoclass:: aiocouchdb.authdb.AuthDatabase
  :members:

Security
--------

.. autoclass:: aiocouchdb.database.Security
  :members:

Document
========

.. autoclass:: aiocouchdb.document.Document
  :members:

.. autoclass:: aiocouchdb.authdb.UserDocument
  :members:

.. autoclass:: aiocouchdb.document.DocAttachmentsMultipartReader
  :members:

.. autoclass:: aiocouchdb.document.OpenRevsMultipartReader
  :members:

Design Document
===============

.. autoclass:: aiocouchdb.designdoc.DesignDocument
  :members:

Attachment
==========

.. autoclass:: aiocouchdb.attachment.Attachment
  :members:

.. autoclass:: aiocouchdb.attachment.AttachmentReader
  :members:

Client
======

.. automodule:: aiocouchdb.client
  :members:

Authentication Providers
========================

.. automodule:: aiocouchdb.authn
  :members:

Feeds
=====

.. automodule:: aiocouchdb.feeds
  :members:

Multipart
=========

.. automodule:: aiocouchdb.multipart
  :members:

Views
=====

.. automodule:: aiocouchdb.views
  :members:

Errors
======

.. automodule:: aiocouchdb.errors
  :members:

Changes
=======

.. include:: ../CHANGES.rst

License
=======

.. literalinclude:: ../LICENSE
